@@ -2,9 +2,9 @@ import argparse
 import sys
 import os
 
-from . import (python, tex)
+from . import (python, scala, tex)
 
-__version__ = '0.3.5.1-beta'
+__version__ = '0.4.0-beta'
 
 
 def get_params():
@@ -69,6 +69,8 @@ def execute_from_command_line():
         python.django(name, directory, repo)
     elif language[0] == 'flask':
         python.flask(name, directory, repo)
+    elif language[0] == 'scala':
+        scala.pure(name, directory, repo)
     elif language[0] == 'tex':
         tex.pure(name, directory, repo)
     else:
